==> wims_4.00.orig.tar.gz: wims-4.00.orig/wims/public_html/scripts/authors/jm.evers/lang/remarks.fr.js <==
var r0="Voulez-vous envoyer cette rponse ?\n";
var r1="Vous n\'avez pas rpondu  la question numro ";
var r2="Votre rponse n\'est pas raliste...<br>Je ne la vrifie pas.";
var r3="J\'ai rcrit la syntaxe sqrt[a](b) pour la racine <br>en une syntaxe b^(1/a)."; 
var r4="Votre rponse contient une virgule<br>Utilisez un point dcimal pour les nombres rels...<br> Si vous voulez donner plusieurs rponses, utilisez des mots comme \"and\" et \"or\" "
var r5="Vous devriez remplacer le caractre \"o\" par le nombre \"0\".";
var r6="Vous essayez de me raconter une histoire.<br> Formulez plutt votre rponse plus srieusement...";
var r7="Vous utilisez la lettre  \"x\" comme symbole de multiplication<br>Utilisez plutt un symbole normal comme \"*\" pour cela ...<br>Ou en cas de rponses multiples, crivez quelque chose comme:<br> x1=123 et x2=456";
var r9="Ecrivez les fonctions avec des parenthses. <br>Ainsi, crivez: sqrt() sin() etc()";
var r10="Vous n\'avez pas utilis la bonne notation scientifique...<br> 5*10^03 == 5*10^3 <br> 5*10^2 == 5e+2<br> 5*10^-6 == 5e-6<br>Pas d\'exposants fractionaires ...";
var r11="Une syntaxe spciale doit tre utilise pour les racines d'ordre suprieure:<br>sqrt[3](11) = \u221B(17) <br> sqrt[4](23) = \u221C(23)";
var r12="J\'ai rcrit votre log[a](b) avec le log en base 10:<br> log(b)/log(a)";
var r13="Je ne veux pas traiter les crochets pour un autre usage que sqrt[] et log[]...[?]<br>Essayez de rcrire votre rponse ";
var r14="Vous devriez rcrire log[10](a) comme log(a).<br>Je vais interprter log(a) comme un logarithme en base 10.";
var r15="Vous devriez rcrire log[e](a) comme ln(a).<br>Je vais interprter ln(a) comme un logarithme en base e.";
var r16="votre rponse n\'a pas de sens...<br>et n\'est pas accepte.";
var r17="c\'est bien sr :<br> log(a)/log(a) = 1<br> Je ne l\'envoie pas...";
var r18="Essayez de formuler votre rponse plus prcisment :<br>quelque chose comme \"sqrt(5++5)\" ou \"log(5--5)\" peut tre crit beaucoup plus simplement...";
var r19="Dans votre dessin,vous avez oubli quelques objets fondamentaux.<br>Voir plus bas:<br><br>"; 
var r20="Votre rponse est illisible et doit tre rcrite.<br><br>"; 
var r21="J\'esprais quelque chose comme:<br> x>123 <br> 12 < x <= 14 <br> Essayez encore...";
var r22="Vous avez oubli de remplir la rponse...";
var r23="Ces divisions longues finissent toutes par le nombre zro (0) et non par ";
var r24="Je ne peux pas en enlever plus...";
var r25="Question :";
var r26=" Vous devriez refaire vos calculs...";
var r27="Dans cet exercice, le pourcentage ne peut tre suprieur  100% ..."
var r28="Dans cet exercice, le pourcentage ne peut tre infrieur  0% ..."
var r29="J\'esprais (finalement) quelque chose comme:<br> x = 123 ...ou quelque chose comme cel <br> Essayez encore ";
var r30="Votre rponse devrait au moins contenir quelques \"flches\" pour indiquer les tapes de votre \"raisonnement\"<br> Regardez les pages d\'aide pour plus d\'info...";
var r31="Le nombre minimal d\'tapes [ flches ->] doit tre : ";
var r32="<br>... ce \"texte\" a t retir de votre rponse.<br> Dans cet exerice, il n\'y en a pas besoin pour dduire la rponse correcte...";
var r33="Si j\'envoie cette rponse  WIMS<br>elle sera trs probablement rejete... ";
var r34="Vous avez t pnalis car votre construction utilisait trop d\'objets.";    
var r35="Vous avez construit:";
var r36="Je m\'attendais  un nombre avec une unit...";
var r37="J\'attendais  un nombre et pas  :";
var r38="ajouter un champ";
var r39="enlever un champ";
var r40="Cliquez sur le bouton \"enlever un champ\" ...";                                                                           
var r41="Cliquez sur le bouton \"ajouter un champ\" ...";                                                                                
var r42="Tous les champs de rponses ont t enlevs ...";                                                                                                
var r43="Pourquoi avez-vous besoin de tant de champs de rponses ?";                                                                                       
var r44="Un des champs de rponses est inutilis..";

==> wims_4.04~dfsg2.orig.tar.gz: wims-4.04~dfsg2/wims/public_html/scripts/authors/jm.evers/lang/remarks.fr.js <==
var r0="Voulez-vous envoyer cette rponse ?\n";
var r1="Vous n\'avez pas rpondu  la question numro ";
var r2="Votre rponse n\'est pas raliste...<br>Je ne la vrifie pas.";
var r3="J\'ai rcrit la syntaxe sqrt[a](b) pour la racine <br>en une syntaxe b^(1/a)."; 
var r4="Votre rponse contient une virgule<br>Utilisez un point dcimal pour les nombres rels...<br> Si vous voulez donner plusieurs rponses, utilisez des mots comme \"and\" et \"or\" "
var r5="Vous devriez remplacer le caractre \"o\" par le nombre \"0\".";
var r6="Vous essayez de me raconter une histoire.<br> Formulez plutt votre rponse plus srieusement...";
var r7="Vous utilisez la lettre  \"x\" comme symbole de multiplication<br>Utilisez plutt un symbole normal comme \"*\" pour cela ...<br>Ou en cas de rponses multiples, crivez quelque chose comme:<br> x1=123 et x2=456";
var r9="Ecrivez les fonctions avec des parenthses. <br>Ainsi, crivez: sqrt() sin() etc()";
var r10="Vous n\'avez pas utilis la bonne notation scientifique...<br> 5*10^03 == 5*10^3 <br> 5*10^2 == 5e+2<br> 5*10^-6 == 5e-6<br>Pas d\'exposants fractionaires ...";
var r11="Une syntaxe spciale doit tre utilise pour les racines d'ordre suprieure:<br>sqrt[3](11) = \u221B(17) <br> sqrt[4](23) = \u221C(23)";
var r12="J\'ai rcrit votre log[a](b) avec le log en base 10:<br> log(b)/log(a)";
var r13="Je ne veux pas traiter les crochets pour un autre usage que sqrt[] et log[]...[?]<br>Essayez de rcrire votre rponse ";
var r14="Vous devriez rcrire log[10](a) comme log(a).<br>Je vais interprter log(a) comme un logarithme en base 10.";
var r15="Vous devriez rcrire log[e](a) comme ln(a).<br>Je vais interprter ln(a) comme un logarithme en base e.";
var r16="votre rponse n\'a pas de sens...<br>et n\'est pas accepte.";
var r17="c\'est bien sr :<br> log(a)/log(a) = 1<br> Je ne l\'envoie pas...";
var r18="Essayez de formuler votre rponse plus prcisment :<br>quelque chose comme \"sqrt(5++5)\" ou \"log(5--5)\" peut tre crit beaucoup plus simplement...";
var r19="Dans votre dessin,vous avez oubli quelques objets fondamentaux.<br>Voir plus bas:<br><br>"; 
var r20="Votre rponse est illisible et doit tre rcrite.<br><br>"; 
var r21="J\'esprais quelque chose comme:<br> x>123 <br> 12 < x <= 14 <br> Essayez encore...";
var r22="Vous avez oubli de remplir la rponse...";
var r23="Ces divisions longues finissent toutes par le nombre zro (0) et non par ";
var r24="Je ne peux pas en enlever plus...";
var r25="Question :";
var r26=" Vous devriez refaire vos calculs...";
var r27="Dans cet exercice, le pourcentage ne peut tre suprieur  100% ..."
var r28="Dans cet exercice, le pourcentage ne peut tre infrieur  0% ..."
var r29="J\'esprais (finalement) quelque chose comme:<br> x = 123 ...ou quelque chose comme cel <br> Essayez encore ";
var r30="Votre rponse devrait au moins contenir quelques \"flches\" pour indiquer les tapes de votre \"raisonnement\"<br> Regardez les pages d\'aide pour plus d\'info...";
var r31="Le nombre minimal d\'tapes [ flches ->] doit tre : ";
var r32="<br>... ce \"texte\" a t retir de votre rponse.<br> Dans cet exercice, il n\'y en a pas besoin pour dduire la rponse correcte...";
var r33="Si j\'envoie cette rponse  WIMS<br>elle sera trs probablement rejete... ";
var r34="Vous avez t pnalis car votre construction utilisait trop d\'objets.";    
var r35="Vous avez construit:";
var r36="Je m\'attendais  un nombre avec une unit...";
var r37="J\'attendais  un nombre et pas  :";
var r38="ajouter un champ";
var r39="enlever un champ";
var r40="Cliquez sur le bouton \"enlever un champ\" ...";                                                                           
var r41="Cliquez sur le bouton \"ajouter un champ\" ...";                                                                                
var r42="Tous les champs de rponses ont t enlevs ...";                                                                                                
var r43="Pourquoi avez-vous besoin de tant de champs de rponses ?";                                                                                       
var r44="Un des champs de rponses est inutilis..";
